==> infrahub_server-1.1.2.tar.gz: infrahub_server-1.1.2/backend/infrahub/core/constants/infrahubkind.py <==
ACCOUNT = "CoreAccount"
ACCOUNTGROUP = "CoreAccountGroup"
ACCOUNTROLE = "CoreAccountRole"
ACCOUNTTOKEN = "InternalAccountToken"
ARTIFACT = "CoreArtifact"
ARTIFACTCHECK = "CoreArtifactCheck"
ARTIFACTDEFINITION = "CoreArtifactDefinition"
ARTIFACTTARGET = "CoreArtifactTarget"
ARTIFACTTHREAD = "CoreArtifactThread"
ARTIFACTVALIDATOR = "CoreArtifactValidator"
BASEPERMISSION = "CoreBasePermission"
CHANGECOMMENT = "CoreChangeComment"
CHANGETHREAD = "CoreChangeThread"
CHECKDEFINITION = "CoreCheckDefinition"
COMMENT = "CoreComment"
CUSTOMWEBHOOK = "CoreCustomWebhook"
CREDENTIAL = "CoreCredential"
DATACHECK = "CoreDataCheck"
DATAVALIDATOR = "CoreDataValidator"
FILECHECK = "CoreFileCheck"
FILETHREAD = "CoreFileThread"
GENERICACCOUNT = "CoreGenericAccount"
GENERATORCHECK = "CoreGeneratorCheck"
GENERATORDEFINITION = "CoreGeneratorDefinition"
GENERATORINSTANCE = "CoreGeneratorInstance"
GENERATORVALIDATOR = "CoreGeneratorValidator"
GENERATORGROUP = "CoreGeneratorGroup"
GENERICGROUP = "CoreGroup"
GLOBALPERMISSION = "CoreGlobalPermission"
GRAPHQLQUERY = "CoreGraphQLQuery"
GRAPHQLQUERYGROUP = "CoreGraphQLQueryGroup"
IPNAMESPACE = "BuiltinIPNamespace"
IPADDRESS = "BuiltinIPAddress"
IPADDRESSPOOL = "CoreIPAddressPool"
IPPREFIX = "BuiltinIPPrefix"
IPPREFIXPOOL = "CoreIPPrefixPool"
MENU = "CoreMenu"
MENUITEM = "CoreMenuItem"
NAMESPACE = "IpamNamespace"
NODE = "CoreNode"
NUMBERPOOL = "CoreNumberPool"
LINEAGEOWNER = "LineageOwner"
LINEAGESOURCE = "LineageSource"
OBJECTPERMISSION = "CoreObjectPermission"
OBJECTTHREAD = "CoreObjectThread"
PASSWORDCREDENTIAL = "CorePasswordCredential"
PROFILE = "CoreProfile"
PROPOSEDCHANGE = "CoreProposedChange"
REFRESHTOKEN = "InternalRefreshToken"
REPOSITORY = "CoreRepository"
RESOURCEPOOL = "CoreResourcePool"
GENERICREPOSITORY = "CoreGenericRepository"
READONLYREPOSITORY = "CoreReadOnlyRepository"
REPOSITORYVALIDATOR = "CoreRepositoryValidator"
SCHEMACHECK = "CoreSchemaCheck"
SCHEMAVALIDATOR = "CoreSchemaValidator"
STANDARDCHECK = "CoreStandardCheck"
STANDARDGROUP = "CoreStandardGroup"
STANDARDWEBHOOK = "CoreStandardWebhook"
TAG = "BuiltinTag"
TASKTARGET = "CoreTaskTarget"
THREAD = "CoreThread"
THREADCOMMENT = "CoreThreadComment"
TRANSFORM = "CoreTransformation"
TRANSFORMJINJA2 = "CoreTransformJinja2"
TRANSFORMPYTHON = "CoreTransformPython"
USERVALIDATOR = "CoreUserValidator"
VALIDATOR = "CoreValidator"
WEBHOOK = "CoreWebhook"

==> infrahub_server-1.2.6.tar.gz: infrahub_server-1.2.6/backend/infrahub/core/constants/infrahubkind.py <==
ACCOUNT = "CoreAccount"
ACCOUNTGROUP = "CoreAccountGroup"
ACCOUNTROLE = "CoreAccountRole"
ACCOUNTTOKEN = "InternalAccountToken"
ARTIFACT = "CoreArtifact"
ARTIFACTCHECK = "CoreArtifactCheck"
ARTIFACTDEFINITION = "CoreArtifactDefinition"
ARTIFACTTARGET = "CoreArtifactTarget"
ARTIFACTTHREAD = "CoreArtifactThread"
ARTIFACTVALIDATOR = "CoreArtifactValidator"
BASEPERMISSION = "CoreBasePermission"
CHANGECOMMENT = "CoreChangeComment"
CHANGETHREAD = "CoreChangeThread"
CHECK = "CoreCheck"
CHECKDEFINITION = "CoreCheckDefinition"
COMMENT = "CoreComment"
CUSTOMWEBHOOK = "CoreCustomWebhook"
CREDENTIAL = "CoreCredential"
DATACHECK = "CoreDataCheck"
DATAVALIDATOR = "CoreDataValidator"
FILECHECK = "CoreFileCheck"
FILETHREAD = "CoreFileThread"
GENERICACCOUNT = "CoreGenericAccount"
GENERATORCHECK = "CoreGeneratorCheck"
GENERATORDEFINITION = "CoreGeneratorDefinition"
GENERATORINSTANCE = "CoreGeneratorInstance"
GENERATORVALIDATOR = "CoreGeneratorValidator"
GENERATORGROUP = "CoreGeneratorGroup"
GENERICGROUP = "CoreGroup"
GLOBALPERMISSION = "CoreGlobalPermission"
GRAPHQLQUERY = "CoreGraphQLQuery"
GRAPHQLQUERYGROUP = "CoreGraphQLQueryGroup"
IPNAMESPACE = "BuiltinIPNamespace"
IPADDRESS = "BuiltinIPAddress"
IPADDRESSPOOL = "CoreIPAddressPool"
IPPREFIX = "BuiltinIPPrefix"
IPPREFIXPOOL = "CoreIPPrefixPool"
MENU = "CoreMenu"
MENUITEM = "CoreMenuItem"
NAMESPACE = "IpamNamespace"
NODE = "CoreNode"
NUMBERPOOL = "CoreNumberPool"
LINEAGEOWNER = "LineageOwner"
LINEAGESOURCE = "LineageSource"
OBJECTCOMPONENTTEMPLATE = "CoreObjectComponentTemplate"
OBJECTPERMISSION = "CoreObjectPermission"
OBJECTTEMPLATE = "CoreObjectTemplate"
OBJECTTHREAD = "CoreObjectThread"
PASSWORDCREDENTIAL = "CorePasswordCredential"
PROFILE = "CoreProfile"
PROPOSEDCHANGE = "CoreProposedChange"
REFRESHTOKEN = "InternalRefreshToken"
REPOSITORY = "CoreRepository"
RESOURCEPOOL = "CoreResourcePool"
GENERICREPOSITORY = "CoreGenericRepository"
READONLYREPOSITORY = "CoreReadOnlyRepository"
REPOSITORYVALIDATOR = "CoreRepositoryValidator"
SCHEMACHECK = "CoreSchemaCheck"
SCHEMAVALIDATOR = "CoreSchemaValidator"
STANDARDCHECK = "CoreStandardCheck"
STANDARDGROUP = "CoreStandardGroup"
STANDARDWEBHOOK = "CoreStandardWebhook"
TAG = "BuiltinTag"
TASKTARGET = "CoreTaskTarget"
THREAD = "CoreThread"
THREADCOMMENT = "CoreThreadComment"
TRANSFORM = "CoreTransformation"
TRANSFORMJINJA2 = "CoreTransformJinja2"
TRANSFORMPYTHON = "CoreTransformPython"
USERVALIDATOR = "CoreUserValidator"
VALIDATOR = "CoreValidator"
WEBHOOK = "CoreWebhook"
